package WebGUI::i18n::Spanish::Asset_Gallery;
use utf8;
our $I18N = {
  'assetName' => {
    'lastUpdated' => '1205245937',
    'message' => 'Galer&iacute;a'
  },
  'defaultFilesPerPage description' => {
    'lastUpdated' => '1216075049',
    'message' => 'El n&uacute;mero de archivos a mostrar por p&aacute;gina de la vista del alb&uacute;m.'
  },
  'defaultFilesPerPage label' => {
    'lastUpdated' => '1224116343',
    'message' => 'Archivos por P&aacute;gina'
  },
  'error add uncommitted' => {
    'lastUpdated' => '1224116376',
    'message' => '<p>Error.</p><p>Debe confirmar &eacute;sta Galer&iacute;a antes de agregar Albums.&nbsp;</p>'
  },
  'groupIdAddComment description' => {
    'lastUpdated' => '1224116416',
    'message' => 'Grupo que puede a&ntilde;adir comentarios a los archivos.'
  },
  'groupIdAddComment label' => {
    'lastUpdated' => '1252532784',
    'message' => 'Grupo para Añadir Comentarios'
  },
  'groupIdAddFile description' => {
    'lastUpdated' => '1224116490',
    'message' => 'Grupo que puede a&ntilde;adir Archivos y Albums a la Galer&iacute;a.'
  },
  'groupIdAddFile label' => {
    'lastUpdated' => '1252532801',
    'message' => 'Grupo para Añadir Archivos'
  },
  'groupIdModerator description' => {
    'lastUpdated' => '1224116568',
    'message' => 'Grupo que puede editar o eliminar comentarios en la Galer&iacute;a.'
  },
  'groupIdModerator label' => {
    'lastUpdated' => '1252532815',
    'message' => 'Grupo para Moderar Comentarios'
  },
  'help common body' => {
    'lastUpdated' => '1224116631',
    'message' => 'Estas variables son comunes a todas las vistas de Galer&iacute;a'
  },
  'help common title' => {
    'lastUpdated' => '1225917077',
    'message' => 'Variables comunes para plantillas de Galer&iacute;as'
  },
  'help listAlbums body' => {
    'lastUpdated' => '1234625077',
    'message' => 'Estas variables estan disponibles en la visualización de listAlbums de la Galería'
  },
  'help listAlbums title' => {
    'lastUpdated' => '1234625096',
    'message' => 'Variables de lista de albums'
  },
  'help listAlbumsRss body' => {
    'lastUpdated' => '1234625129',
    'message' => 'Estas variables estas disponibles en el feed RSS listAlbums.'
  },
  'help listAlbumsRss title' => {
    'lastUpdated' => '1252532873',
    'message' => 'Variables de Fuentes RSS para Albumes en Galería'
  },
  'help listFilesForUser body' => {
    'lastUpdated' => '1252532896',
    'message' => 'Estas variables están disponibles en la pantalla listFileForUser de la Galería.'
  },
  'help listFilesForUser title' => {
    'lastUpdated' => '1252532931',
    'message' => 'Variables para Listar Archivos en la Galería'
  },
  'help listFilesForUserRss body' => {
    'lastUpdated' => '1252532950',
    'message' => 'Estas variables están disponibles en la Fuente RSS listFilesForUser.'
  },
  'help listFilesForUserRss title' => {
    'lastUpdated' => '1252532967',
    'message' => 'Variables para Fuente RSS de Listar Archivos en Galería'
  },
  'help search body' => {
    'lastUpdated' => '1216074885',
    'message' => 'Estas variables estan disponibles desde la pantalla de resultados de la b&uacute;squeda de la galer&iacute;a.'
  },
  'help search title' => {
    'lastUpdated' => '1216473176',
    'message' => 'Variables de resultados de la busceda en la Galeria'
  },
  'help searchForm body' => {
    'lastUpdated' => '1252532998',
    'message' => 'Estas variables están disponibles en la Galería y permiten crear formulares de búsqueda sobre la Galería.'
  },
  'help searchForm title' => {
    'lastUpdated' => '1252533014',
    'message' => 'Variables para Búsqueda en Galería'
  },
  'helpvar albums' => {
    'lastUpdated' => '1252533036',
    'message' => 'Un ciclo sobre los Albumes que se están mostrando.'
  },
  'helpvar albums rss' => {
    'lastUpdated' => '1252533056',
    'message' => 'Un ciclo que contiene la Fuente RSS para los Albumes en la Galería.'
  },
  'helpvar canAddFile' => {
    'lastUpdated' => '1252533091',
    'message' => 'Un condicional que indica si el usuario puede o no agregar Albumes y Archivos a la Galería.'
  },
  'helpvar canEdit' => {
    'lastUpdated' => '1215796769',
    'message' => 'Esta variable es verdadera si el usuario puede editar la galer&iacute;a.'
  },
  'helpvar isAlbum' => {
    'lastUpdated' => '1252533113',
    'message' => 'Un condicional que indica si el resultado actual es un Album de Galería.'
  },
  'helpvar rssDate' => {
    'lastUpdated' => '1252533138',
    'message' => 'Fecha en formato RFC-2822 para el campo pubDate de la Fuente RSS.'
  },
  'helpvar searchForm_basicSearch' => {
    'lastUpdated' => '1252533167',
    'message' => 'El campo básico de búsqueda. Buscará sobre título, descripción, palabras claves y campos definidos por el usuario.'
  },
  'helpvar searchForm_className' => {
    'lastUpdated' => '1252533196',
    'message' => 'Buscar por clase.'
  },
  'helpvar searchForm_creationDate_after' => {
    'lastUpdated' => '1252533326',
    'message' => 'Limitar la búsqueda sobre Activos creados después de la fecha indicada.'
  },
  'helpvar searchForm_creationDate_before' => {
    'lastUpdated' => '1252533357',
    'message' => 'Limitar la búsqueda sobre Activos creados antes de la fecha indicada.'
  },
  'helpvar searchForm_description' => {
    'lastUpdated' => '1252533365',
    'message' => 'Buscar por descripción'
  },
  'helpvar searchForm_end' => {
    'lastUpdated' => '1252533385',
    'message' => 'Terminar el formulario de búsqueda sobre la Galería.'
  },
  'helpvar searchForm_keywords' => {
    'lastUpdated' => '1252533394',
    'message' => 'Buscar por palabra clave'
  },
  'helpvar searchForm_location' => {
    'lastUpdated' => '1276810148',
    'message' => 'Buscar por ubicación.'
  },
  'helpvar searchForm_start' => {
    'lastUpdated' => '1252533408',
    'message' => 'Comenzar el formulario de búsqueda en Galería.'
  },
  'helpvar searchForm_submit' => {
    'lastUpdated' => '1252533424',
    'message' => 'Iniciar la búsqueda'
  },
  'helpvar searchForm_title' => {
    'lastUpdated' => '1252533433',
    'message' => 'Buscar por título'
  },
  'helpvar search_results' => {
    'lastUpdated' => '1252533445',
    'message' => 'Un ciclo sobre los resultados de la búsqueda.'
  },
  'helpvar url_addAlbum' => {
    'lastUpdated' => '1252533456',
    'message' => 'URL para agregar un Album a la Galería.'
  },
  'helpvar url_listAlbums' => {
    'lastUpdated' => '1252533468',
    'message' => 'URL a la lista de Albumes en la Galería.'
  },
  'helpvar url_listAlbumsRss' => {
    'lastUpdated' => '1252533482',
    'message' => 'URL a la Fuente RSS de la lista de Albumes de la Galería.'
  },
  'helpvar url_listFilesForCurrentUser' => {
    'lastUpdated' => '1252533499',
    'message' => 'URL a la lista de Albumes y Archivos para el usuario actual.'
  },
  'helpvar url_rss' => {
    'lastUpdated' => '1252533545',
    'message' => 'El URL a la Fuente RSS para los Archivos y Albumes de este usuario.'
  },
  'helpvar url_search' => {
    'lastUpdated' => '1252533571',
    'message' => 'URL a la página de búsqueda'
  },
  'helpvar userId' => {
    'lastUpdated' => '1252533601',
    'message' => 'El ID del usuario mostrado en la página listFilesForUser.'
  },
  'helpvar user_albums' => {
    'lastUpdated' => '1252533619',
    'message' => 'Un ciclo sobre todos los Albumes del usuario.'
  },
  'helpvar user_files' => {
    'lastUpdated' => '1252533658',
    'message' => 'Un ciclo sobre los Archivos del usuario. Solamente los archivos en la página actual de resultados serán presentados.'
  },
  'helpvar username' => {
    'lastUpdated' => '1252533682',
    'message' => 'El nombre de usuario actualmente mostrado en la página listFilesForUser.'
  },
  'imageDensity description' => {
    'lastUpdated' => '1252533716',
    'message' => 'La densidad de la imagen. Las imágenes con calidad de impresión tienen una resolución tres o más veces mayor que las imáges con calidad para Web.'
  },
  'imageDensity label' => {
    'lastUpdated' => '1252533731',
    'message' => 'Densidad de Imágenes'
  },
  'imageDensity option print' => {
    'lastUpdated' => '1252533753',
    'message' => 'Calidad para imprimir (300 pixels por pulgada)'
  },
  'imageDensity option web' => {
    'lastUpdated' => '1252533770',
    'message' => 'Calidad para Web (72 pixels por pulgada)'
  },
  'imageResolutions description' => {
    'lastUpdated' => '1252533801',
    'message' => 'El tamaño en pixels de las imágenes disponibles para descargar. Este número es la altura o anchura máxima que la imagen puede tener.'
  },
  'imageResolutions label' => {
    'lastUpdated' => '1233073324',
    'message' => 'Resoluciones de Imagen'
  },
  'imageThumbnailSize description' => {
    'lastUpdated' => '1252533837',
    'message' => 'El tamaño en pixels para las miniaturas de las imágenes en la Galería. Utilizará el valor por defecto definido en la Configuración del sitio.'
  },
  'imageThumbnailSize label' => {
    'lastUpdated' => '1252533852',
    'message' => 'Tamaño de la Miniatura'
  },
  'imageViewSize description' => {
    'lastUpdated' => '1252533894',
    'message' => 'El tamaño en pixels para las imágenes en la Galería. Tomará el valor por defecto establecido en la Configuración del sitio.'
  },
  'imageViewSize label' => {
    'lastUpdated' => '1252533928',
    'message' => 'Tamaño para Mostrar Imágenes'
  },
  'maxSpacePerUser description' => {
    'lastUpdated' => '1252533974',
    'message' => 'Cantidad máxima de espacio en disco en megabytes que un usuario puede ocupar en esta Galería. Cada imagen puede tomar hasta 6Mb dependiendo de las resoluciones y densidad escogidas.'
  },
  'maxSpacePerUser label' => {
    'lastUpdated' => '1252533999',
    'message' => 'Límite de Espacio por Usuario'
  },
  'richEditIdAlbum description' => {
    'lastUpdated' => '1252534024',
    'message' => 'El Editor Extendido a utilizar en los Albumes.'
  },
  'richEditIdAlbum label' => {
    'lastUpdated' => '1252534036',
    'message' => 'Editor para Albumes'
  },
  'richEditIdFile description' => {
    'lastUpdated' => '1252534050',
    'message' => 'El Editor Extendido a utilizar para los Archivos.'
  },
  'richEditIdFile label' => {
    'lastUpdated' => '1252534058',
    'message' => 'Editor para Archivos'
  },
  'richEditIdFileComment description' => {
    'lastUpdated' => '1252534074',
    'message' => 'El Editor Extendido a utilizar en los comentarios.'
  },
  'richEditIdFileComment label' => {
    'lastUpdated' => '1252534083',
    'message' => 'Editor para Comentarios'
  },
  'search class any' => {
    'lastUpdated' => '1252534090',
    'message' => 'Cualquiera'
  },
  'search class galleryalbum' => {
    'lastUpdated' => '1252534096',
    'message' => 'Album'
  },
  'search class photo' => {
    'lastUpdated' => '1252534102',
    'message' => 'Foto'
  },
  'search submit' => {
    'lastUpdated' => '1252534107',
    'message' => 'Buscar'
  },
  'template by' => {
    'lastUpdated' => '1252534119',
    'message' => 'Por'
  },
  'template galleryalbum url' => {
    'lastUpdated' => '1252534125',
    'message' => 'Ver Album'
  },
  'template listAlbumsRss' => {
    'lastUpdated' => '1252534133',
    'message' => 'Suscribir'
  },
  'template listFilesForUser albums files' => {
    'lastUpdated' => '1252534142',
    'message' => 'archivos'
  },
  'template listFilesForUser albums title' => {
    'lastUpdated' => '1252534153',
    'message' => 'Mis Albumes'
  },
  'template listFilesForUser pictures title' => {
    'lastUpdated' => '1252534168',
    'message' => 'Mis Imágenes'
  },
  'template listFilesForUser title' => {
    'lastUpdated' => '1252534187',
    'message' => 'Galería de %s'
  },
  'template search basic term' => {
    'lastUpdated' => '1252534208',
    'message' => 'Términos de Búsqueda'
  },
  'template search basic title' => {
    'lastUpdated' => '1252534222',
    'message' => 'Buscar en la Galería'
  },
  'template search field className' => {
    'lastUpdated' => '1252534235',
    'message' => 'Tipo de Búsqueda'
  },
  'template search field creationDate' => {
    'lastUpdated' => '1252534242',
    'message' => 'Fecha'
  },
  'template search field description' => {
    'lastUpdated' => '1252534249',
    'message' => 'Descripción'
  },
  'template search field keywords' => {
    'lastUpdated' => '1252535972',
    'message' => 'Etiquetas'
  },
  'template search field location' => {
    'lastUpdated' => '1276810131',
    'message' => 'Ubicación'
  },
  'template search field title' => {
    'lastUpdated' => '1252534265',
    'message' => 'Título'
  },
  'template search results for' => {
    'lastUpdated' => '1252534283',
    'message' => 'Resultados de buscar'
  },
  'template search title' => {
    'lastUpdated' => '1252534293',
    'message' => 'Búsqueda Avanzada'
  },
  'template search to' => {
    'lastUpdated' => '1252534306',
    'message' => 'hasta'
  },
  'template url_addAlbum' => {
    'lastUpdated' => '1252534314',
    'message' => 'Agregar un Album'
  },
  'template url_listFilesForCurrentUser' => {
    'lastUpdated' => '1252534322',
    'message' => 'Mi Galería'
  },
  'template url_search' => {
    'lastUpdated' => '1252534331',
    'message' => 'Búsqueda Avanzada'
  },
  'templateIdAddArchive description' => {
    'lastUpdated' => '1252534354',
    'message' => 'Despliegua el formulario para agregar un conjunto de archivos a la Galería.'
  },
  'templateIdAddArchive label' => {
    'lastUpdated' => '1233073356',
    'message' => 'Plantilla para Agregar Múltiples'
  },
  'templateIdDeleteAlbum description' => {
    'lastUpdated' => '1252534590',
    'message' => 'Seleccione la Plantilla para desplegar la confirmación para eliminar un Album de la Galería.'
  },
  'templateIdDeleteAlbum label' => {
    'lastUpdated' => '1252534385',
    'message' => 'Plantilla para Eliminar Albumes'
  },
  'templateIdDeleteFile description' => {
    'lastUpdated' => '1252534564',
    'message' => 'Seleccione la Plantilla para desplegar la confirmación de eliminación de archivos de la Galería.'
  },
  'templateIdDeleteFile label' => {
    'lastUpdated' => '1252534420',
    'message' => 'Plantilla para Eliminar Archivos'
  },
  'templateIdEditAlbum description' => {
    'lastUpdated' => '1252534544',
    'message' => 'Seleccione la Plantilla para agregar o editar un Album.'
  },
  'templateIdEditAlbum label' => {
    'lastUpdated' => '1252534440',
    'message' => 'Plantilla para Editar Albúm'
  },
  'templateIdEditComment description' => {
    'lastUpdated' => '1252534529',
    'message' => 'Seleccione la Plantilla para agregar o editar comentarios.'
  },
  'templateIdEditComment label' => {
    'lastUpdated' => '1233074859',
    'message' => 'Plantilla para Editar Comentarios'
  },
  'templateIdEditFile description' => {
    'lastUpdated' => '1252534513',
    'message' => 'Seleccione la Plantilla para agregar o editar un Archivo.'
  },
  'templateIdEditFile label' => {
    'lastUpdated' => '1233074831',
    'message' => 'Plantilla para Editar Archivos'
  },
  'templateIdListAlbums description' => {
    'lastUpdated' => '1252534613',
    'message' => 'Seleccione la Plantilla para desplegar el listado de Albumes en la Galería.'
  },
  'templateIdListAlbums label' => {
    'lastUpdated' => '1233074892',
    'message' => 'Plantilla para Listar Albumes'
  },
  'templateIdListAlbumsRss description' => {
    'lastUpdated' => '1252534636',
    'message' => 'Seleccione la Plantilla para desplegar la Fuente RSS de los Albumes en la Galería.'
  },
  'templateIdListAlbumsRss label' => {
    'lastUpdated' => '1252534652',
    'message' => 'Plantilla para Fuente RSS Lista de Albumes'
  },
  'templateIdListFilesForUser description' => {
    'lastUpdated' => '1252534682',
    'message' => 'Seleccione la Plantilla para desplegar los Archivos y Albumes de un usuario específico.'
  },
  'templateIdListFilesForUser label' => {
    'lastUpdated' => '1252534795',
    'message' => 'Plantilla para Listar Archivos de un Usuario'
  },
  'templateIdListFilesForUserRss description' => {
    'lastUpdated' => '1252534818',
    'message' => 'Seleccione la Plantilla para desplegar la Fuente RSS para los Archivos de un usuario específico.'
  },
  'templateIdListFilesForUserRss label' => {
    'lastUpdated' => '1252534835',
    'message' => 'Plantilla para Fuente RSS de Archivos de un Usuario'
  },
  'templateIdMakeShortcut description' => {
    'lastUpdated' => '1252534853',
    'message' => 'Seleccione la Plantilla para copiar una imagen hacia otro Album.'
  },
  'templateIdMakeShortcut label' => {
    'lastUpdated' => '1252534873',
    'message' => 'Plantilla para Copiar Archivos'
  },
  'templateIdSearch description' => {
    'lastUpdated' => '1252534904',
    'message' => 'Seleccione la Plantilla para desplegar el formulario de búsqueda sobre Galería y sus resultados.'
  },
  'templateIdSearch label' => {
    'lastUpdated' => '1252534920',
    'message' => 'Plantilla para Búsqueda'
  },
  'templateIdViewAlbum description' => {
    'lastUpdated' => '1252534947',
    'message' => 'Seleccione la Plantilla para desplegar Albumes.'
  },
  'templateIdViewAlbum label' => {
    'lastUpdated' => '1252534957',
    'message' => 'Plantilla para Ver Album'
  },
  'templateIdViewAlbumRss description' => {
    'lastUpdated' => '1252534975',
    'message' => 'Seleccione la Plantilla para presentar la Fuente RSS de un Album.'
  },
  'templateIdViewAlbumRss label' => {
    'lastUpdated' => '1252534988',
    'message' => 'Plantilla para Fuente RSS de un Album'
  },
  'templateIdViewFile description' => {
    'lastUpdated' => '1252535013',
    'message' => 'Seleccione la Plantilla para mostrar los detalles y comentarios de un Archivo específico.'
  },
  'templateIdViewFile label' => {
    'lastUpdated' => '1252535022',
    'message' => 'Plantilla para Ver Archivo'
  },
  'templateIdViewSlideshow description' => {
    'lastUpdated' => '1252535049',
    'message' => 'Seleccione la Plantilla para mostrar todas las imágenes de un Album como una presentación continua.'
  },
  'templateIdViewSlideshow label' => {
    'lastUpdated' => '1252535059',
    'message' => 'Plantilla para Slideshow'
  },
  'templateIdViewThumbnails description' => {
    'lastUpdated' => '1252535075',
    'message' => 'Seleccione la Plantilla para mostrar el Album como miniaturas.'
  },
  'templateIdViewThumbnails label' => {
    'lastUpdated' => '1252535085',
    'message' => 'Plantilla para Miniaturas'
  },
  'viewAlbumAssetId description' => {
    'lastUpdated' => '1252535113',
    'message' => 'El Album a mostrar cuando la vista por defecto es \'Album Sencillo\''
  },
  'viewAlbumAssetId label' => {
    'lastUpdated' => '1252535184',
    'message' => 'Album por Defecto'
  },
  'viewDefault description' => {
    'lastUpdated' => '1252535156',
    'message' => 'Seleccione la presentación por omisión cuando un usuario ingrese a la Galería.'
  },
  'viewDefault label' => {
    'lastUpdated' => '1252535173',
    'message' => 'Vista por Defecto'
  },
  'viewDefault option album' => {
    'lastUpdated' => '1252535194',
    'message' => 'Album Sencillo'
  },
  'viewDefault option list' => {
    'lastUpdated' => '1252535202',
    'message' => 'Lista de Albumes'
  },
  'viewListOrderBy description' => {
    'lastUpdated' => '1252535221',
    'message' => 'El campo sobre el cual ordenar el listado del Album'
  },
  'viewListOrderBy label' => {
    'lastUpdated' => '1252535741',
    'message' => 'Listar Albumes ordenados por'
  },
  'viewListOrderBy option creationDate' => {
    'lastUpdated' => '1252535235',
    'message' => 'Fecha de Creación'
  },
  'viewListOrderBy option lineage' => {
    'lastUpdated' => '1252535767',
    'message' => 'Número de Secuencia'
  },
  'viewListOrderBy option revisionDate' => {
    'lastUpdated' => '1252535775',
    'message' => 'Fecha de Revisión'
  },
  'viewListOrderBy option title' => {
    'lastUpdated' => '1252535781',
    'message' => 'Título'
  },
  'viewListOrderDirection description' => {
    'lastUpdated' => '1252535794',
    'message' => 'Dirección de ordenamiento.'
  },
  'viewListOrderDirection label' => {
    'lastUpdated' => '1252535811',
    'message' => 'Listar en orden'
  },
  'viewListOrderDirection option asc' => {
    'lastUpdated' => '1252535818',
    'message' => 'Ascendente'
  },
  'viewListOrderDirection option desc' => {
    'lastUpdated' => '1252535826',
    'message' => 'Descendente'
  },
  'workflowIdCommit description' => {
    'lastUpdated' => '1252535839',
    'message' => 'Flujo de Trabajo para Aprobar Archivos'
  },
  'workflowIdCommit label' => {
    'lastUpdated' => '1252535850',
    'message' => 'Flujo de Trabajo para Aprobación'
  }
}
;

1;
